{
  stdenv,
  lib,
  fetchFromGitHub,
  unzip,
  wineWowPackages,
  luajit,
  copyDesktopItems,
  makeDesktopItem,
}:
stdenv.mkDerivation rec {
  pname = "path-of-building-poe2";
  version = "v0.3.0";

  src = fetchFromGitHub {
    owner = "PathOfBuildingCommunity";
    repo = "PathOfBuilding-PoE2";
    rev = "${version}";
    hash = "sha256-eIT5QWadpIAgRLCQpA80D3wKmtikSnP6wBqj3TqkUPs=";
  };

  nativeBuildInputs = [unzip] ++ lib.optional stdenv.hostPlatform.isLinux copyDesktopItems;

  buildInputs = [
    # wineWowPackages.base.out
    # luajit
    # luajit.pkgs.lua-curl
  ];

  installPhase = ''
        runHook preInstall

        # I have absolutely no idea how this file is generated
        # and I don't think I want to know. The Flatpak also does this.
        unzip -j -d $out $src/runtime-win32.zip lua/sha1.lua

        # Install the actual data
        # cp -r $src/src $src/runtime/lua/*.lua $src/manifest.xml $out
        cp -r $src/* $out

        # Pretend this is an official build so we don't get the ugly "dev mode" warning
        substituteInPlace $out/manifest.xml --replace '<Version' '<Version platform="nixos"'
        substituteInPlace $out/manifest.xml --replace '<Version' '<Version branch="master"'
        touch $out/installed.cfg

    #     touch $out/src/Settings.xml
    #     chmod +w $out/src/Settings.xml
    #     echo '<?xml version="1.0" encoding="UTF-8"?>
    # <PathOfBuilding2>
    # 	<Mode mode="BUILD">
    # 		<Arg boolean="false"/>
    # 		<Arg string="Unnamed build"/>
    # 	</Mode>
    # 	<Accounts/>
    # 	<SharedItems/>
    # 	<Misc betaTest="nil" connectionProtocol="0" colorNegative="^xDD0022" thousandsSeparator="," showThousandsSeparators="true" colorPositive="^x33FF77" buildSortMode="NAME" showPublicBuilds="true" edgeSearchHighlight="true" POESESSID="" showTitlebarName="true" invertSliderScrollDirection="nil" disableDevAutoSave="nil" colorHighlight="^xFF0000" slotOnlyTooltips="true" defaultCharLevel="1" showWarnings="true" decimalSeparator="." defaultGemQuality="0" defaultItemAffixQuality="0.5" nodePowerTheme="RED/BLUE" buildPath="/home/snorre/Documents/PathOfBuilding"/>
    # </PathOfBuilding2>
    # ' > $out/src/Settings.xml

        # Completely stub out the update check
        chmod +w $out/src/UpdateCheck.lua
        echo 'return "none"' > $out/src/UpdateCheck.lua

        runHook postInstall
  '';

  desktopItems = [
    (makeDesktopItem {
      name = "path-of-building-poe2";
      desktopName = "Path of Building for PoE2";
      comment = "Offline build planner for Path of Exile 2";
      exec = "nix-shell -p wineWowPackages.base.out --run \"wine ${src}/runtime/Path{space}of{space}Building-PoE2.exe %U\"";
      terminal = false;
      type = "Application";
      icon = "pathofbuilding";
      categories = ["Game"];
      keywords = [
        "poe"
        "pob"
        "pobc"
        "path"
        "exile"
      ];
      mimeTypes = ["x-scheme-handler/pob"];
    })
  ];

  meta = {
    description = "Offline build planner for Path of Exile 2";
    homepage = "https://pathofbuilding.community/";
    license = lib.licenses.mit;
    maintainers = [];
    mainProgram = "pob2frontend";
    broken = stdenv.hostPlatform.isDarwin; # doesn't find uic6 for some reason
  };
}
